==> forestry_1.10.2-5.2.17.362-sources.jar: forestry/core/gui/slots/SlotForestry.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.core.gui.slots;

import forestry.core.gui.tooltips.IToolTipProvider;
import forestry.core.gui.tooltips.ToolTip;
import forestry.core.render.TextureManager;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.inventory.Slot;
import net.minecraft.item.ItemStack;
import net.minecraftforge.fml.common.FMLCommonHandler;
import net.minecraftforge.fml.relauncher.Side;

public class SlotForestry extends Slot implements IToolTipProvider {

	private boolean isPhantom;
	private boolean canAdjustPhantom = true;
	private boolean canShift = true;
	private int stackLimit;
	private ToolTip toolTips;

	public SlotForestry(IInventory inventory, int slotIndex, int xPos, int yPos) {
		super(inventory, slotIndex, xPos, yPos);
		if (inventory == null) {
			throw new IllegalArgumentException("Inventory must not be null");
		}
		if (FMLCommonHandler.instance().getEffectiveSide() == Side.CLIENT) {
			setBackgroundLocation(TextureManager.getInstance().getGuiTextureMap());
		}
		this.stackLimit = -1;
	}

	public SlotForestry setPhantom() {
		isPhantom = true;
		return this;
	}

	public SlotForestry blockShift() {
		canShift = false;
		return this;
	}

	@Override
	public void func_75215_d(ItemStack itemStack) {
		if (!isPhantom() || canAdjustPhantom()) {
			super.func_75215_d(itemStack);
		}
	}

	public SlotForestry setCanAdjustPhantom(boolean canAdjust) {
		this.canAdjustPhantom = canAdjust;
		return this;
	}

	public SlotForestry setStackLimit(int limit) {
		this.stackLimit = limit;
		return this;
	}

	public boolean isPhantom() {
		return this.isPhantom;
	}

	public boolean canAdjustPhantom() {
		return canAdjustPhantom;
	}

	@Override
	public boolean func_82869_a(EntityPlayer stack) {
		return !isPhantom();
	}

	public boolean canShift() {
		return canShift;
	}

	@Override
	public int func_75219_a() {
		if (stackLimit < 0) {
			return super.func_75219_a();
		} else {
			return stackLimit;
		}
	}

	/**
	 * @param toolTips the tooltips to set
	 */
	public void setToolTips(ToolTip toolTips) {
		this.toolTips = toolTips;
	}

	/**
	 * @return the toolTips
	 * @param mouseX
	 * @param mouseY
	 */
	@Override
	public ToolTip getToolTip(int mouseX, int mouseY) {
		return toolTips;
	}

	@Override
	public boolean isToolTipVisible() {
		return func_75211_c() == null;
	}

	@Override
	public boolean isMouseOver(int mouseX, int mouseY) {
		return mouseX >= field_75223_e && mouseX <= field_75223_e + 16 && mouseY >= field_75221_f && mouseY <= field_75221_f + 16;
	}
}

==> forestry_1.11.2-5.3.0.15-sources.jar: forestry/core/gui/slots/SlotForestry.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.core.gui.slots;

import javax.annotation.Nullable;

import forestry.core.gui.tooltips.IToolTipProvider;
import forestry.core.gui.tooltips.ToolTip;
import forestry.core.render.TextureManager;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.inventory.Slot;
import net.minecraft.item.ItemStack;
import net.minecraftforge.fml.common.FMLCommonHandler;
import net.minecraftforge.fml.relauncher.Side;

public class SlotForestry extends Slot implements IToolTipProvider {

	private boolean isPhantom;
	private boolean canAdjustPhantom = true;
	private boolean canShift = true;
	private int stackLimit;
	@Nullable
	private ToolTip toolTips;

	public SlotForestry(IInventory inventory, int slotIndex, int xPos, int yPos) {
		super(inventory, slotIndex, xPos, yPos);
		if (FMLCommonHandler.instance().getEffectiveSide() == Side.CLIENT) {
			setBackgroundLocation(TextureManager.getInstance().getGuiTextureMap());
		}
		this.stackLimit = -1;
	}

	public SlotForestry setPhantom() {
		isPhantom = true;
		return this;
	}

	public SlotForestry blockShift() {
		canShift = false;
		return this;
	}

	@Override
	public void func_75215_d(ItemStack itemStack) {
		if (!isPhantom() || canAdjustPhantom()) {
			super.func_75215_d(itemStack);
		}
	}

	public SlotForestry setCanAdjustPhantom(boolean canAdjust) {
		this.canAdjustPhantom = canAdjust;
		return this;
	}

	public SlotForestry setStackLimit(int limit) {
		this.stackLimit = limit;
		return this;
	}

	public boolean isPhantom() {
		return this.isPhantom;
	}

	public boolean canAdjustPhantom() {
		return canAdjustPhantom;
	}

	@Override
	public boolean func_82869_a(EntityPlayer stack) {
		return !isPhantom();
	}

	public boolean canShift() {
		return canShift;
	}

	@Override
	public int func_75219_a() {
		if (stackLimit < 0) {
			return super.func_75219_a();
		} else {
			return stackLimit;
		}
	}

	public void setToolTips(ToolTip toolTips) {
		this.toolTips = toolTips;
	}

	@Override
	public ToolTip getToolTip(int mouseX, int mouseY) {
		return toolTips;
	}

	@Override
	public boolean isToolTipVisible() {
		return func_75211_c().func_190926_b();
	}

	@Override
	public boolean isMouseOver(int mouseX, int mouseY) {
		return mouseX >= field_75223_e && mouseX <= field_75223_e + 16 && mouseY >= field_75221_f && mouseY <= field_75221_f + 16;
	}
}
